@@ -16,14 +16,25 @@
  */
 #include <afsconfig.h>
 #include "afs/param.h"
-
-RCSID
-    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_groups.c,v 1.5 2003/07/15 23:14:17 shadow Exp $");
-
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
+#include "afs/opr.h"
 #include "afs/afs_stats.h"	/* statistics */
 
+/* We should be doing something better anyway */
+#ifdef AFS_DARWIN80_ENV
+int
+setpag(proc, cred, pagvalue, newpag, change_parent)
+     struct proc *proc;
+     struct ucred **cred;
+     afs_uint32 pagvalue;
+     afs_uint32 *newpag;
+     afs_uint32 change_parent;
+{ 
+    return EINVAL;
+}
+#else
+
 static int
   afs_getgroups(struct ucred *cred, int ngroups, gid_t * gidset);
 
@@ -74,7 +85,6 @@ Afs_xsetgroups(p, args, retval)
     return code;
 }
 
-
 int
 setpag(proc, cred, pagvalue, newpag, change_parent)
      struct proc *proc;
@@ -113,7 +123,7 @@ afs_getgroups(struct ucred *cred, int ngroups, gid_t * gidset)
     gid_t *gp;
 
     AFS_STATCNT(afs_getgroups);
-    savengrps = ngrps = MIN(ngroups, cred->cr_ngroups);
+    savengrps = ngrps = opr_min(ngroups, cred->cr_ngroups);
     gp = cred->cr_groups;
     while (ngrps--)
 	*gidset++ = *gp++;
@@ -159,3 +169,4 @@ afs_setgroups(struct proc *proc, struct ucred **cred, int ngroups,
     crfree(oldcr);
     return (0);
 }
+#endif
